grep-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

grep branch, master, updated. v2.10-86-gfff5850


From: Paul Eggert
Subject: grep branch, master, updated. v2.10-86-gfff5850
Date: Fri, 02 Mar 2012 01:12:07 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "grep".

The branch, master has been updated
       via  fff5850967ec10fa3e2e4a800031cb8e335e8fca (commit)
      from  8fcf61523644df42e1905c81bed26838e0b04f91 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://git.savannah.gnu.org/cgit/grep.git/commit/?id=fff5850967ec10fa3e2e4a800031cb8e335e8fca


commit fff5850967ec10fa3e2e4a800031cb8e335e8fca
Author: Paul Eggert <address@hidden>
Date:   Thu Mar 1 17:04:32 2012 -0800

    maint: spelling fixes

diff --git a/AUTHORS b/AUTHORS
index 55bc714..1423c8b 100644
--- a/AUTHORS
+++ b/AUTHORS
@@ -41,7 +41,7 @@ for complete details and credits.
 Arnold Robbins contributed to improve dfa.[ch]. In fact
 it came straight from gawk-3.0.3 with small editing and fixes.
 
-Many folks contributed see THANKS, if I omited someone please
+Many folks contributed.  See THANKS; if I omitted someone please
 send me email.
 
 Alain Magloire maintained GNU grep until version 2.5e.
diff --git a/Makefile.boot b/Makefile.boot
index 5c2993c..043429b 100644
--- a/Makefile.boot
+++ b/Makefile.boot
@@ -108,7 +108,7 @@ DEFS_ansi_c = -DPROTOTYPES
 # DEFS_wchar =  -Dwchar_t=int -Dmbstate_t=int
 DEFS_wchar =  -DHAVE_WCHAR_H
 
-# Is strtol() and strtoul()  declarared ?
+# Are strtol() and strtoul() declared?
 #DEFS_strtol = -DHAVE_DECL_STRTOULL=0 -DHAVE_DECL_STRTOUL=0
 DEFS_strtol = -DHAVE_DECL_STRTOULL=1 -DHAVE_DECL_STRTOUL=1
 
diff --git a/NEWS b/NEWS
index 5ff4027..4a530a6 100644
--- a/NEWS
+++ b/NEWS
@@ -344,7 +344,7 @@ Version 2.5
     consistency, and partly because POSIX.2 recommends against
     optional arguments.
 
-  - The new -P or --perl-regexp option tells grep to interpert the pattern as
+  - The new -P or --perl-regexp option tells grep to interpret the pattern as
     a Perl regular expression.
 
   - The new option --max-count=num makes grep stop reading a file after num
@@ -469,7 +469,7 @@ This is a bug fix release(see Changelog) i.e. no new 
features.
 
   - More compliance to GNU standard.
   - Long options.
-  - Internationalisation.
+  - Internationalization.
   - Use automake/autoconf.
   - Directory hierarchy change.
   - Sigvec with -e on Linux corrected.
diff --git a/README-boot b/README-boot
index 2b4bb57..88bead7 100644
--- a/README-boot
+++ b/README-boot
@@ -5,7 +5,7 @@
   notice and this notice are preserved.
 
 If your system is lacking the necessary tools to build the configuration,
-Makefile.boot is provided for bootstraping.  Invoke it with the following
+Makefile.boot is provided for bootstrapping.  Invoke it with the following
 command:
 
   (cd src && make -f ../Makefile.boot)
diff --git a/TODO b/TODO
index 9d4bb73..ae8a5b4 100644
--- a/TODO
+++ b/TODO
@@ -79,7 +79,7 @@ but POSIX does not standardize any method for accessing this 
information!
 For Unicode, interesting things to check include the Unicode Standard
 <http://www.unicode.org/standard/standard.html> and the Unicode Technical
 Standard #18 (<http://www.unicode.org/reports/tr18/> “Unicode Regular
-Expressions”).  Talk to Bruno Haible who's mantaining GNU libunistring.
+Expressions”).  Talk to Bruno Haible who's maintaining GNU libunistring.
 See also Unicode Standard Annex #15 (<http://www.unicode.org/reports/tr15/>
 “Unicode Normalization Forms”), already implemented by GNU libunistring.
 
diff --git a/cfg.mk b/cfg.mk
index 5040199..a495959 100644
--- a/cfg.mk
+++ b/cfg.mk
@@ -31,7 +31,7 @@ bootstrap-tools = autoconf,automake,gnulib
 # Now that we have better tests, make this the default.
 export VERBOSE = yes
 
-old_NEWS_hash = 25ce2f420ad2d0f4ec68b23237691054
+old_NEWS_hash = 83c4de7ac0356eb3814cd97161e3e742
 
 # Many m4 macros names once began with `jm_'.
 # Make sure that none are inadvertently reintroduced.
diff --git a/doc/grep.texi b/doc/grep.texi
index de73d7f..5381a30 100644
--- a/doc/grep.texi
+++ b/doc/grep.texi
@@ -1015,7 +1015,7 @@ instead of strict equality with@ 2.
 @node grep Programs
 @section @command{grep} Programs
 @cindex @command{grep} programs
address@hidden variants of @command{gerp}
address@hidden variants of @command{grep}
 
 @command{grep} searches the named input files
 for lines containing a match to the given pattern.
@@ -1178,7 +1178,7 @@ that respectively match the concatenated expressions.
 
 Two regular expressions may be joined by the infix operator @samp{|};
 the resulting regular expression
-matches any string matching either alternalte expression.
+matches any string matching either alternate expression.
 
 Repetition takes precedence over concatenation,
 which in turn takes precedence over alternation.
diff --git a/src/dfa.c b/src/dfa.c
index 4c9071f..2a69025 100644
--- a/src/dfa.c
+++ b/src/dfa.c
@@ -206,7 +206,7 @@ enum
                                    the beginning or end of a word. */
 
   QMARK,                       /* QMARK is an operator of one argument that
-                                   matches zero or one occurences of its
+                                   matches zero or one occurrences of its
                                    argument. */
 
   STAR,                                /* STAR is an operator of one argument 
that
@@ -346,7 +346,7 @@ struct dfa
                  single-byte characters.
 
        if tokens[i] = MBCSET
-         ("the index of mbcsets correspnd to this operator" << 2) + 3
+         ("the index of mbcsets corresponding to this operator" << 2) + 3
 
      e.g.
      tokens
@@ -751,7 +751,7 @@ static unsigned char *mblen_buf;/* Correspond to the input 
buffer in dfaexec().
                                    byte of corresponding multibyte character
                                    in the input string.  A element's value
                                    is 0 if corresponding character is a
-                                   single byte chracter.
+                                   single byte character.
                                    e.g. input : 'a', <mb(0)>, <mb(1)>, <mb(2)>
                                     mblen_buf :   0,       3,       2,       1
                                 */
@@ -2972,11 +2972,11 @@ match_mb_charset (struct dfa *d, state_num s, position 
pos, size_t idx)
   char buffer[128];
   wchar_t wcbuf[6];
 
-  /* Pointer to the structure to which we are currently refering.  */
+  /* Pointer to the structure to which we are currently referring.  */
   struct mb_char_classes *work_mbc;
 
   int context;
-  wchar_t wc;          /* Current refering character.  */
+  wchar_t wc;          /* Current referring character.  */
 
   wc = inputwcs[idx];
 
@@ -2996,7 +2996,7 @@ match_mb_charset (struct dfa *d, state_num s, position 
pos, size_t idx)
   if (!SUCCEEDS_IN_CONTEXT(pos.constraint, d->states[s].context, context))
     return 0;
 
-  /* Assign the current refering operator to work_mbc.  */
+  /* Assign the current referring operator to work_mbc.  */
   work_mbc = &(d->mbcsets[(d->multibyte_prop[pos.index]) >> 2]);
   match = !work_mbc->invert;
   match_len = (mblen_buf[idx] == 0)? 1 : mblen_buf[idx];
@@ -3135,7 +3135,7 @@ transit_state_consume_1char (struct dfa *d, state_num s,
   /* Copy the positions contained by `s1' to the set `pps'.  */
   copy(&(d->states[s1].elems), pps);
 
-  /* Check (inputed)match_lens, and initialize if it is NULL.  */
+  /* Check (input) match_lens, and initialize if it is NULL.  */
   if (match_lens == NULL && d->states[s].mbps.nelem != 0)
     work_mbls = check_matching_with_multibyte_ops(d, s, *pp - buf_begin);
   else
@@ -3978,7 +3978,7 @@ dfamust (struct dfa *d)
             rmp = --mp;
             lmp = --mp;
             /* In.  Everything in left, plus everything in
-               right, plus catenation of
+               right, plus concatenation of
                left's right and right's left. */
             lmp->in = addlists(lmp->in, rmp->in);
             if (lmp->in == NULL)
diff --git a/src/dfasearch.c b/src/dfasearch.c
index ffb8bb1..bd09aa6 100644
--- a/src/dfasearch.c
+++ b/src/dfasearch.c
@@ -332,7 +332,7 @@ EGexecute (char const *buf, size_t size, size_t *match_size,
                 }
               /* If -w, check if the match aligns with word boundaries.
                  We do this iteratively because:
-                 (a) the line may contain more than one occurence of the
+                 (a) the line may contain more than one occurrence of the
                  pattern, and
                  (b) Several alternatives in the pattern might be valid at a
                  given point, and we may need to consider a shorter one to
diff --git a/src/main.c b/src/main.c
index 7d83f4d..2f6c761 100644
--- a/src/main.c
+++ b/src/main.c
@@ -1789,7 +1789,7 @@ main (int argc, char **argv)
 
   /* The value -1 means to use DEFAULT_CONTEXT. */
   out_after = out_before = -1;
-  /* Default before/after context: chaged by -C/-NUM options */
+  /* Default before/after context: changed by -C/-NUM options */
   default_context = 0;
   /* Changed by -o option */
   only_matching = 0;
diff --git a/tests/fedora b/tests/fedora
index 304ca8a..d26b40e 100755
--- a/tests/fedora
+++ b/tests/fedora
@@ -8,7 +8,7 @@
 
 if [ -t 1 ]
 then
-        # Colored output on terimal
+        # Colored output on terminal
         G='\033[32m'
         R='\033[31m'
         D='\033[0m'

-----------------------------------------------------------------------

Summary of changes:
 AUTHORS         |    2 +-
 Makefile.boot   |    2 +-
 NEWS            |    4 ++--
 README-boot     |    2 +-
 TODO            |    2 +-
 cfg.mk          |    2 +-
 doc/grep.texi   |    4 ++--
 src/dfa.c       |   16 ++++++++--------
 src/dfasearch.c |    2 +-
 src/kwset.c     |   14 +++++++-------
 src/main.c      |    2 +-
 tests/fedora    |    2 +-
 12 files changed, 27 insertions(+), 27 deletions(-)


hooks/post-receive
diff --git a/src/kwset.c b/src/kwset.c
index 5496371..cd40953 100644
--- a/src/kwset.c
+++ b/src/kwset.c
@@ -21,7 +21,7 @@
    The author may be reached (Email) at the address address@hidden,
    or (US mail) as Mike Haertel c/o Free Software Foundation. */
 
-/* The algorithm implemented by these routines bears a startling resemblence
+/* The algorithm implemented by these routines bears a startling resemblance
    to one discovered by Beate Commentz-Walter, although it is not identical.
    See "A String Matching Algorithm Fast on the Average," Technical Report,
    IBM-Germany, Scientific Center Heidelberg, Tiergartenstrasse 15, D-6900
@@ -69,7 +69,7 @@ struct trie
   struct trie *fail;           /* Aho-Corasick failure function. */
   int depth;                   /* Depth of this node from the root. */
   int shift;                   /* Shift function for search failures. */
-  int maxshift;                        /* Max shift of self and descendents. */
+  int maxshift;                        /* Max shift of self and descendants. */
 };
 
 /* Structure returned opaquely to the caller, containing everything. */
@@ -314,7 +314,7 @@ treefails (struct tree const *tree, struct trie const *fail,
   treefails(tree->rlink, fail, recourse);
 
   /* Find, in the chain of fails going back to the root, the first
-     node that has a descendent on the current label. */
+     node that has a descendant on the current label. */
   while (fail)
     {
       link = fail->links;
@@ -432,16 +432,16 @@ kwsprep (kwset_t kws)
          computing the delta table, failure function, and shift function. */
       for (curr = last = kwset->trie; curr; curr = curr->next)
         {
           /* Enqueue the immediate descendents in the level order queue. */
           enqueue(curr->links, &last);
 
           curr->shift = kwset->mind;
           curr->maxshift = kwset->mind;
 
           /* Update the delta table for the descendents of this node. */
           treedelta(curr->links, curr->depth, delta);
 
           /* Compute the failure function for the decendents of this node. */
           treefails(curr->links, curr->fail, kwset->trie);
 
           /* Update the shifts at each node in the current node's chain
@@ -456,7 +456,7 @@ kwsprep (kwset_t kws)
                   fail->shift = curr->depth - fail->depth;
 
               /* If the current node is accepting then the shift at the
-                 fail and its descendents should be no larger than the
+                 fail and its descendants should be no larger than the
                  difference of their depths. */
               if (curr->accepting && fail->maxshift > curr->depth - 
@@ -432,16 +432,16 @@ kwsprep (kwset_t kws)
       for (curr = last = kwset->trie; curr; curr = curr->next)
         {
-          /* Enqueue the immediate descendents in the level order queue. */
+          /* Enqueue the immediate descendants in the level order queue. */
           enqueue(curr->links, &last);
 
@@ -432,16 +432,16 @@ kwsprep (kwset_t kws)
           curr->maxshift = kwset->mind;
 
-          /* Update the delta table for the descendents of this node. */
+          /* Update the delta table for the descendants of this node. */
           treedelta(curr->links, curr->depth, delta);
 
@@ -432,16 +432,16 @@ kwsprep (kwset_t kws)
           treedelta(curr->links, curr->depth, delta);
 
-          /* Compute the failure function for the decendents of this node. */
+          /* Compute the failure function for the descendants of this node.  */
           treefails(curr->links, curr->fail, kwset->trie);
 
fail->depth)
                 fail->maxshift = curr->depth - fail->depth;
-- 
grep



reply via email to

[Prev in Thread] Current Thread [Next in Thread]